"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Auth = void 0;
const axios_1 = require("axios");
const simple_oauth2_1 = require("simple-oauth2");
class Auth {
    constructor(config) {
        this.tokenExpirationBufferMs = 10 * 1000;
        this.audience = "";
        const t = new URL(config.tokenUrl);
        this.audience = config.audience;
        this.scopes = config.scopes;
        this.customOptions = config.customOptions;
        this.clientCredentialsAuth = new simple_oauth2_1.ClientCredentials({
            options: {
                bodyFormat: 'json'
            },
            client: {
                id: config.clientId,
                secret: config.clientSecret
            },
            auth: {
                tokenHost: t.origin,
                tokenPath: t.pathname,
            },
        });
    }
    async generateNewToken() {
        const tokenConfig = {
            scope: this.scopes, audience: this.audience, custom_claims: this.customOptions
        };
        const startTime = Date.now();
        const tokenResult = await this.clientCredentialsAuth.getToken(tokenConfig);
        this.token = tokenResult.token.access_token;
        this.tokenExpirationTimeMs = startTime + tokenResult.token.expires_in * 1000;
    }
    isTokenValid() {
        if (!this.token)
            return false;
        if (this.tokenExpirationTimeMs && this.tokenExpirationTimeMs < Date.now() + this.tokenExpirationBufferMs)
            return false;
        return true;
    }
    async getToken() {
        if (!this.token || !this.isTokenValid()) {
            await this.generateNewToken();
        }
        return this.token;
    }
    async getHeaders() {
        const headers = new axios_1.AxiosHeaders();
        const token = await this.getToken();
        headers.set("Authorization", `Bearer ${token}`);
        return headers;
    }
}
exports.Auth = Auth;
;
