"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupsClient = void 0;
const genericClient_js_1 = require("./genericClient.js");
const groupMembersClient_js_1 = require("./groupMembersClient.js");
class GroupsClient {
    constructor(basePath, auth, queryOptions) {
        this.auth = auth;
        this.basePath = basePath;
        this.queryOptions = queryOptions;
        this.client = new genericClient_js_1.GenericClient({
            basePath: basePath,
            endpointPath: "/groups",
            auth: auth,
            writeTypeName: "GroupWrite",
            singleResponseTypeName: "WrappedGroup",
            multipleResponseTypeName: "WrappedWithMetaArrayGroup",
            queryOptions: queryOptions,
        });
    }
    async create(group) {
        return this.client.create(group);
    }
    async remove(id) {
        return this.client.remove(id);
    }
    async get(id, query = {}) {
        return this.client.get(id, query);
    }
    async find(findParams = {}) {
        return this.client.find(findParams);
    }
    async update(id, group) {
        return this.client.update(id, group);
    }
    getGroupMembersClient(groupUid) {
        return new groupMembersClient_js_1.GroupMembersClient(this.basePath, groupUid, this.auth, this.queryOptions);
    }
    async getMember(groupUid, memberUid, query = {}) {
        const membersClient = this.getGroupMembersClient(groupUid);
        return membersClient.get(memberUid, query);
    }
    async findMembers(groupUid, findParams = {}) {
        const membersClient = this.getGroupMembersClient(groupUid);
        return membersClient.find(findParams);
    }
    async addMember(groupUid, member) {
        const membersClient = this.getGroupMembersClient(groupUid);
        return membersClient.create(member);
    }
    async removeMember(groupUid, memberUid) {
        const membersClient = this.getGroupMembersClient(groupUid);
        return membersClient.remove(memberUid);
    }
    async removeMemberByPersonUid(groupUid, personUid) {
        const membersClient = this.getGroupMembersClient(groupUid);
        return membersClient.removeByPersonUid(personUid);
    }
}
exports.GroupsClient = GroupsClient;
