"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_js_1 = require("./helpers.js");
const api_js_1 = require("../api.js");
const error_js_1 = require("../model/error.js");
const scopes_js_1 = require("../configuration/scopes.js");
describe("Errors", async () => {
    it("Test error helpers", () => {
        function throwFunction() {
            throw new error_js_1.CoreApiError({
                error: {
                    code: api_js_1.ErrorCode.InvalidBody,
                    message: "test message",
                },
            });
        }
        try {
            throwFunction();
        }
        catch (err) {
            if (!(0, api_js_1.isCoreApiError)(err))
                throw "Invalid error type";
            chai_1.assert.equal(err.details.code, api_js_1.ErrorCode.InvalidBody);
            chai_1.assert.equal(err.message, "test message");
        }
    });
    it("Invalid scope error", async () => {
        try {
            const config = (0, helpers_js_1.getDefaultConfig)();
            config.scopes = [scopes_js_1.Scope.ConsentsRead];
            const clientWithOutScope = new api_js_1.CoreApiClient(config);
            await clientWithOutScope.affiliations.get(helpers_js_1.affiliationUid);
            chai_1.assert.fail("Was able to remove with an invalid scope");
        }
        catch (err) {
            if (!(err instanceof error_js_1.CoreApiError))
                chai_1.assert.fail("Invalid error type");
            chai_1.assert.equal(err.details.code, api_js_1.ErrorCode.MissingScopes);
            chai_1.assert.equal(err.message, "missing scope: needs: persons.affiliations#read");
        }
    });
    it("Non existing error", async () => {
        try {
            const fakeUid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
            await helpers_js_1.client.affiliations.get(fakeUid);
            chai_1.assert.fail("Was able to remove with a non existing affiliation");
        }
        catch (err) {
            if (!(err instanceof error_js_1.CoreApiError))
                chai_1.assert.fail("Invalid error type");
            chai_1.assert.equal(err.details.code, api_js_1.ErrorCode.NotFound);
        }
    });
});
