import axios from "axios";
import { Environment, defaultEnvironmentConfig, } from "../configuration/environments.js";
import { Scope } from "../configuration/scopes.js";
import { AffiliationsClient } from "./affiliationsClient.js";
import { Auth } from "./auth.js";
import { ConsentsClient } from "./consentsClient.js";
import { CountriesClient } from "./countriesClient.js";
import { OrgsClient } from "./orgsClient.js";
import { PersonsClient } from "./personsClient.js";
import { RelationsClient } from "./relationsClient.js";
import { RoleAssignmentsClient } from "./roleAssignmentsClient.js";
import { RolesClient } from "./rolesClient.js";
import { GroupsClient } from "./groupsClient.js";
export class CoreApiClient {
    get affiliations() {
        return this._affiliations;
    }
    get consents() {
        return this._consents;
    }
    get countries() {
        return this._countries;
    }
    get orgs() {
        return this._orgs;
    }
    get persons() {
        return this._persons;
    }
    get relations() {
        return this._relations;
    }
    get roles() {
        return this._roles;
    }
    get roleAssignments() {
        return this._roleAssignments;
    }
    get groups() {
        return this._groups;
    }
    constructor(config) {
        const env = config.environment;
        this.queryOptions = Object.assign(getDefaultQueryOptions(), config.queryOptions);
        this.auth = new Auth({
            audience: config.customOauthAudience ??
                defaultEnvironmentConfig[env].oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: config.scopes ??
                (env === Environment.Emulator ? Object.values(Scope) : undefined),
            tokenUrl: config.customOauthTokenUrl ?? defaultEnvironmentConfig[env].tokenUrl,
            customOptions: config.customOptions ??
                (env === Environment.Emulator ? { orgs: "-" } : undefined),
        });
        this.basePath =
            config.customApiBaseUrl ?? defaultEnvironmentConfig[env].apiBaseUrl;
        this._affiliations = new AffiliationsClient(this.basePath, this.auth, this.queryOptions);
        this._consents = new ConsentsClient(this.basePath, this.auth, this.queryOptions);
        this._countries = new CountriesClient(this.basePath, this.auth, this.queryOptions);
        this._orgs = new OrgsClient(this.basePath, this.auth, this.queryOptions);
        this._persons = new PersonsClient(this.basePath, this.auth, this.queryOptions);
        this._relations = new RelationsClient(this.basePath, this.auth, this.queryOptions);
        this._roles = new RolesClient(this.basePath, this.auth, this.queryOptions);
        this._roleAssignments = new RoleAssignmentsClient(this.basePath, this.auth, this.queryOptions);
        this._groups = new GroupsClient(this.basePath, this.auth, this.queryOptions);
    }
    async refreshTestData() {
        return axios.post(this.basePath + "/refresh-data");
    }
    async getToken() {
        return this.auth.getToken();
    }
}
function getDefaultQueryOptions() {
    return {
        includePersonsWithoutChurchAffiliation: false,
        includeInactive: [],
    };
}
