import axios from "axios";
import { ObjectSerializer } from "../api.js";
import { CoreApiError } from "../model/error.js";
import { serializeFindQueryParams, serializeGetQueryParams, } from "../model/queryParams.js";
export class GenericClient {
    constructor(config) {
        this.config = config;
        this.httpClient = axios.create({
            validateStatus: () => true,
        });
    }
    async create(data) {
        const url = this.config.basePath + this.config.endpointPath;
        const res = await this.httpClient.post(url, ObjectSerializer.serialize(data, this.config.writeTypeName), {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
    async get(id, getParams = {}) {
        getParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), getParams.options);
        const queryParams = serializeGetQueryParams(getParams);
        const url = this.config.basePath +
            this.config.endpointPath +
            "/" +
            id +
            "?" +
            queryParams;
        const res = await this.httpClient.get(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
    async find(findParams = {}) {
        findParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), findParams.options);
        const queryParams = serializeFindQueryParams(findParams);
        const url = this.config.basePath + this.config.endpointPath + "?" + queryParams;
        const res = await this.httpClient.get(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, this.config.multipleResponseTypeName);
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
    async update(id, data) {
        const url = this.config.basePath + this.config.endpointPath + "/" + id;
        const res = await this.httpClient.put(url, JSON.stringify(ObjectSerializer.serialize(data, this.config.writeTypeName)), {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
    async remove(id) {
        const url = this.config.basePath + this.config.endpointPath + "/" + id;
        const res = await this.httpClient.delete(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
}
