import axios from "axios";
import { ObjectSerializer, } from "../api.js";
import { GenericClient } from "./genericClient.js";
import { CoreApiError } from "../model/error.js";
export class GroupMembersClient {
    constructor(basePath, groupUid, auth, queryOptions) {
        this.basePath = basePath;
        this.groupUid = groupUid;
        this.auth = auth;
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: `/groups/${groupUid}/members`,
            auth: auth,
            writeTypeName: "GroupMemberWrite",
            singleResponseTypeName: "WrappedGroupMember",
            multipleResponseTypeName: "WrappedWithMetaArrayGroupMember",
            queryOptions: queryOptions,
        });
    }
    async create(groupMember) {
        return this.client.create(groupMember);
    }
    async remove(id) {
        return this.client.remove(id);
    }
    async removeByPersonUid(personUid) {
        const url = `${this.basePath}/groups/${this.groupUid}/members?personUid=${personUid}`;
        const res = await axios.delete(url, {
            headers: await this.auth.getHeaders(),
            validateStatus: () => true,
        });
        if (res.status === 200) {
            const result = ObjectSerializer.deserialize(res.data, "WrappedGroupMember");
            return result;
        }
        else {
            throw CoreApiError.fromHttpResponse(res);
        }
    }
    async get(id, query = {}) {
        return this.client.get(id, query);
    }
    async find(findParams = {}) {
        return this.client.find(findParams);
    }
}
