import { assert } from "chai";
import { delay } from "./helpers.js";
import { Auth } from "../api/auth.js";
import Sinon from "sinon";
import { Environment, defaultEnvironmentConfig, } from "../configuration/environments.js";
describe("Auth", async () => {
    const auth = new Auth({
        audience: defaultEnvironmentConfig[Environment.Emulator].oauthAudience,
        clientId: "0000",
        clientSecret: "0000",
        tokenUrl: defaultEnvironmentConfig[Environment.Emulator].tokenUrl,
    });
    it("Authenticate token gets reused", async () => {
        const t1 = await auth.getToken();
        await delay(1000);
        const t2 = await auth.getToken();
        assert.equal(t1, t2);
    });
    it("Authenticate expired token gets refreshed", async () => {
        const t1 = await auth.getToken();
        await delay(1000);
        const fakeClock = Sinon.useFakeTimers(new Date());
        fakeClock.tick(2 * 24 * 60 * 60 * 1000);
        const t2 = await auth.getToken();
        fakeClock.restore();
        assert.notEqual(t1, t2);
    });
});
