import { assert } from "chai";
import { client, countryUid, getDefaultConfig } from "./helpers.js";
import { Scope } from "../configuration/scopes.js";
import { CoreApiClient, ErrorCode, isCoreApiError } from "../api.js";
describe("Countries", async () => {
    it("Countries find", async () => {
        const result = await client.countries.find();
        const country = result.data.find((c) => c.nameEn === "Netherlands");
        if (!country)
            throw Error("Country not defined");
        assert.equal(country.uid, countryUid);
        assert.equal(country.nameNative, "Nederland");
        assert.equal(country.nameNo, "Nederland");
    });
    it("Countries find with invalid scope", async () => {
        try {
            const config = getDefaultConfig();
            config.scopes = [Scope.PersonsRead];
            const clientWithOutScope = new CoreApiClient(config);
            await clientWithOutScope.countries.find();
            assert.fail("Was able to find with an invalid scope");
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw Error("Invalid error type");
            assert.equal(err.details.code, ErrorCode.MissingScopes);
        }
    });
});
